@@ -3,7 +3,7 @@
 
 /* function prototypes for the direct and inverse gnomonic projections */
 
-Datum	gnomonic_proj(PG_FUNCTION_ARGS);
-Datum	gnomonic_inv(PG_FUNCTION_ARGS);
+extern Datum gnomonic_proj(PG_FUNCTION_ARGS);
+extern Datum gnomonic_inv(PG_FUNCTION_ARGS);
 
 #endif
